#include "userprog/syscall.h"
#include <stdio.h>
#include <syscall-nr.h>
#include "threads/interrupt.h"
#include "threads/thread.h"

void sys_halt (void);
void sys_exit (int status);
pid_t sys_exec (const char *cmd_line);
int sys_wait (pid_t pid);
bool sys_create (const char *name, unsigned int initial_size);
bool sys_remove (const char *file)
int sys_open (const char *file);
int sys_filesize (int fd);
int sys_read (int fd, void *buffer, unsigned length);
void sys_write (int fd, const void *buffer, unsigned int length);
void sys_seek (int fd, unsigned position);
unsigned sys_tell (int fd);
void sys_close (int fd);

static void syscall_handler (struct intr_frame *f);{
	int code = (int) load_stack (f, ARG_CODE);

	switch (code)
	{
		case SYS_HALT:
			sys_halt();
			break;
		case SYS_EXIT:
			sys_exit ((int) load_stack (f, ARG_0));
			break;
		case SYS_CLOSE:
			sys_close ((int) load_stack (f, ARG_0));
			break;
		}
}

void sys_halt (void)
{
	shutdown_power_off();
}

void sys_exit (int status)
{
	struct thread *cur = thread_current ();
	cur->exit_status = status
		thread_exit();
}

int sys_wait (pid_t pid)
{
	return process_wait (pid);
}

void
syscall_init (void) 
{
  intr_register_int (0x30, 3, INTR_ON, syscall_handler, "syscall");
}


static void
syscall_handler (struct intr_frame *f UNUSED)
{
  printf ("system call!\n");
  thread_exit ();
}
